@@ -1,3 +1,3 @@
-require 'backports/tools'
+require 'backports/tools/alias_method'
 
 Backports.alias_method Dir, :to_path, :path
