@@ -1,5 +1,5 @@
 if RUBY_VERSION < '1.9'
-  require 'backports/tools'
+  require 'backports/tools/path'
 
   Backports.convert_all_arguments_to_path File, :join, 0
 end
