@@ -1,10 +1,13 @@
 unless Enumerable.method_defined? :flat_map
-  require 'backports/1.8.7/array/flatten'
-
   module Enumerable
-    def flat_map(&block)
+    def flat_map
       return to_enum(:flat_map) unless block_given?
-      map(&block).flatten(1)
+      r = []
+      each do |*args|
+        result = yield(*args)
+        result.respond_to?(:to_ary) ? r.concat(result) : r.push(result)
+      end
+      r
     end
     alias_method :collect_concat, :flat_map
   end
